@@ -5,8 +5,11 @@ extern crate serde_json;
 
 
 #[derive(Debug, Serialize, Deserialize)]
-pub struct SearchResponse<T, V = Vec<String>> {
-    pub took: i8,
+pub struct SearchResponse<T, V = Value> {
+    #[serde(default)]
+    pub _scroll_id: String,
+    #[serde(default)]
+    pub took: usize,
     pub hits: Hits<T>,
     #[serde(default)]
     pub aggregations: V,
@@ -22,13 +25,29 @@ pub struct HitsTotal {
 
 #[derive(Debug, Serialize, Deserialize)]
 pub struct Hits<T> {
-    pub total: HitsTotal,
-    #[serde(default)]
-    pub max_score: f32,
-    pub hits: Vec<Hit<T>>,
+    pub total: Option<HitsTotal>,
+    pub max_score: Option<f32>,
+    pub hits: Option<Vec<Hit<T>>>,
 }
 
-#[derive(Debug, Serialize, Deserialize)]
+// impl<T> Hits<T> {
+//     fn total(&self) -> HitsTotal {
+//         return match self.total.clone() {
+//             Some(v) => { v }
+//             None => {
+//                 HitsTotal {
+//                     value: 0,
+//                     relation: "".to_string(),
+//                 }
+//             }
+//         };
+//     }
+//     fn max_score(&self) -> f32 {
+//         self.max_score.unwrap_or(0.0)
+//     }
+// }
+
+#[derive(Debug, Serialize, Deserialize, Default, Clone)]
 pub struct Hit<T> {
     #[serde(default)]
     pub _index: String,
@@ -42,6 +61,7 @@ pub struct Hit<T> {
 }
 
 use serde::de;
+use serde_json::Value;
 
 pub fn parse<'a, T>(s: &'a str) -> T
     where
